@@ -150,6 +150,9 @@ def test_tabix_intervals():
     assert len(a.tabix_intervals('chr1:30-35[-]')) == 0
     assert len(a.tabix_intervals('chr1:29-30[-]')) == 1
 
+    # permit fetching of a contig without a specified region
+    assert len(a.tabix_intervals('chr1')) == 1
+
 # ----------------------------------------------------------------------------
 # Streaming and non-file BedTool tests
 # ----------------------------------------------------------------------------
@@ -1952,50 +1955,55 @@ def test_issue_156():
     # that lists of filenames works.
     a = pybedtools.example_bedtool('a.bed')
     b = [pybedtools.example_filename('b.bed'), pybedtools.example_filename('c.gff')]
-    assert str(a.intersect(b)) == fix(
+    res = str(a.intersect(b))
+    assert res == fix(
         """
-        chr1	60	100	feature1	0	+
-        chr1	155	200	feature2	0	+
-        chr1	174	200	feature2	0	+
-        chr1	174	200	feature2	0	+
-        chr1	100	200	feature2	0	+
-        chr1	155	200	feature3	0	-
-        chr1	465	500	feature3	0	-
-        chr1	486	500	feature3	0	-
-        chr1	174	326	feature3	0	-
-        chr1	439	500	feature3	0	-
-        chr1	496	500	feature3	0	-
-        chr1	486	500	feature3	0	-
-        chr1	174	326	feature3	0	-
-        chr1	439	500	feature3	0	-
-        chr1	150	269	feature3	0	-
-        chr1	900	901	feature4	0	+
-        chr1	900	913	feature4	0	+
-        chr1	900	913	feature4	0	+
-        chr1	900	950	feature4	0	+
-        """)
-    assert str(a.intersect(b, wb=True, names=['B', 'C'])) == fix(
+        chr1    59      100     feature1        0       +
+        chr1    155     200     feature2        0       +
+        chr1    173     200     feature2        0       +
+        chr1    173     200     feature2        0       +
+        chr1    100     200     feature2        0       +
+        chr1    155     200     feature3        0       -
+        chr1    464     500     feature3        0       -
+        chr1    485     500     feature3        0       -
+        chr1    173     326     feature3        0       -
+        chr1    438     500     feature3        0       -
+        chr1    495     500     feature3        0       -
+        chr1    485     500     feature3        0       -
+        chr1    173     326     feature3        0       -
+        chr1    438     500     feature3        0       -
+        chr1    150     269     feature3        0       -
+        chr1    900     901     feature4        0       +
+        chr1    900     913     feature4        0       +
+        chr1    900     913     feature4        0       +
+        chr1    900     950     feature4        0       +
+        """), res
+
+    res = str(a.intersect(b, wb=True, names=['B', 'C']))
+    assert res == fix(
         """
-        chr1	60	100	feature1	0	+	C	chr1	ucb	gene	60	269	.	-	.	ID=thaliana_1_6160_6269;match=fgenesh1_pg.C_scaffold_1000119;rname=thaliana_1_6160_6269
+        chr1	59	100	feature1	0	+	C	chr1	ucb	gene	60	269	.	-	.	ID=thaliana_1_6160_6269;match=fgenesh1_pg.C_scaffold_1000119;rname=thaliana_1_6160_6269
         chr1	155	200	feature2	0	+	B	chr1	155	200	feature5	0	-
-        chr1	174	200	feature2	0	+	C	chr1	ucb	CDS	174	326	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
-        chr1	174	200	feature2	0	+	C	chr1	ucb	mRNA	174	326	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
+        chr1	173	200	feature2	0	+	C	chr1	ucb	CDS	174	326	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
+        chr1	173	200	feature2	0	+	C	chr1	ucb	mRNA	174	326	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
         chr1	100	200	feature2	0	+	C	chr1	ucb	gene	60	269	.	-	.	ID=thaliana_1_6160_6269;match=fgenesh1_pg.C_scaffold_1000119;rname=thaliana_1_6160_6269
         chr1	155	200	feature3	0	-	B	chr1	155	200	feature5	0	-
-        chr1	465	500	feature3	0	-	C	chr1	ucb	gene	465	805	.	+	.	ID=thaliana_1_465_805;match=scaffold_801404.1;rname=thaliana_1_465_805
-        chr1	486	500	feature3	0	-	C	chr1	ucb	CDS	486	605	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
-        chr1	174	326	feature3	0	-	C	chr1	ucb	CDS	174	326	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
-        chr1	439	500	feature3	0	-	C	chr1	ucb	CDS	439	630	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
-        chr1	496	500	feature3	0	-	C	chr1	ucb	mRNA	496	576	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
-        chr1	486	500	feature3	0	-	C	chr1	ucb	mRNA	486	605	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
-        chr1	174	326	feature3	0	-	C	chr1	ucb	mRNA	174	326	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
-        chr1	439	500	feature3	0	-	C	chr1	ucb	mRNA	439	899	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
+        chr1	464	500	feature3	0	-	C	chr1	ucb	gene	465	805	.	+	.	ID=thaliana_1_465_805;match=scaffold_801404.1;rname=thaliana_1_465_805
+        chr1	485	500	feature3	0	-	C	chr1	ucb	CDS	486	605	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
+        chr1	173	326	feature3	0	-	C	chr1	ucb	CDS	174	326	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
+        chr1	438	500	feature3	0	-	C	chr1	ucb	CDS	439	630	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
+        chr1	495	500	feature3	0	-	C	chr1	ucb	mRNA	496	576	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
+        chr1	485	500	feature3	0	-	C	chr1	ucb	mRNA	486	605	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
+        chr1	173	326	feature3	0	-	C	chr1	ucb	mRNA	174	326	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
+        chr1	438	500	feature3	0	-	C	chr1	ucb	mRNA	439	899	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
         chr1	150	269	feature3	0	-	C	chr1	ucb	gene	60	269	.	-	.	ID=thaliana_1_6160_6269;match=fgenesh1_pg.C_scaffold_1000119;rname=thaliana_1_6160_6269
         chr1	900	901	feature4	0	+	B	chr1	800	901	feature6	0	+
         chr1	900	913	feature4	0	+	C	chr1	ucb	mRNA	631	913	.	+	.	ID=AT1G01010.mRNA;Parent=AT1G01010;rname=AT1G01010
         chr1	900	913	feature4	0	+	C	chr1	ucb	CDS	760	913	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
         chr1	900	950	feature4	0	+	C	chr1	ucb	CDS	706	1095	.	+	.	Parent=AT1G01010.mRNA;rname=AT1G01010
-        """)
+        """), res
+
+
 
 def test_issue_157():
     # the problem here was that converting to file from dataframe didn't pass
@@ -2066,3 +2074,48 @@ def test_issue_169():
     line = gzip.open(fn, 'rt').readline()
     assert str(line).startswith('#'), line
 
+def test_issue_196():
+    bed = pybedtools.BedTool(
+        '''
+        8 129185980 129186130 A 0.1
+        8 129185980 129186130 B 0.2
+        ''', from_string=True)
+    bed = bed.tabix()
+    snp = pybedtools.BedTool("8\t129186110\t129186111\trs72722756", from_string=True)
+    intersection = bed.tabix_intervals('{}:{}-{}'.format("8",129186110,129186111)).intersect(snp, wa=True, wb=True)
+
+    # prior to fixing this issue, intervals would be concatenated. This was
+    # because pysam.ctabix.tabixIterator does not include newlines when
+    # yielding. The incorrect output was this:
+    '''
+    8   129185980   129186130   A   0.18   129185980   129186130   B   0.2   8   129186110   129186111   rs72722756
+    '''
+
+    # but should be this:
+    assert intersection == fix(
+        '''
+        8       129185980       129186130       A       0.1     8       129186110       129186111       rs72722756
+        8       129185980       129186130       B       0.2     8       129186110       129186111       rs72722756
+        ''')
+
+
+def test_issue_178():
+    fn = pybedtools.example_filename('gdc.othersort.bam')
+    pybedtools.contrib.bigwig.bam_to_bigwig(fn, genome='dm3', output='tmp.bw')
+    x = pybedtools.contrib.bigwig.bigwig_to_bedgraph('tmp.bw')
+    assert x == fix(
+        '''
+        chr2L   70      75      1
+        chr2L   140     145     1
+        chr2L   150     155     1
+        chr2L   160     165     1
+        chr2L   210     215     1
+        chrX    10      15      1
+        chrX    70      75      1
+        chrX    140     145     1
+        ''')
+    os.unlink('tmp.bw')
+
+def test_issue_203():
+    x = pybedtools.example_bedtool('x.bed')
+    x.truncate_to_chrom(genome='hg19')
